@@ -1,17 +1,13 @@
-from collections import OrderedDict
+import argparse
+import copy
 import json
+import logging
 import time
 import uuid
-import argparse
-import logging
-import copy
+from collections import OrderedDict
 from datetime import datetime
 
-from wzdx.tools import polygon_tools, date_tools, array_tools
-
-from wzdx.util.transformations import rfc_to_unix
-from wzdx.util.transformations import int_or_none
-from wzdx.util.transformations import to_dict
+from wzdx.tools import array_tools, date_tools, polygon_tools
 from wzdx.util.collections import PathDict
 
 PROGRAM_NAME = 'Navjoy568RawToStandard'
@@ -124,12 +120,7 @@ def expand_speed_zone(message):
     try:
         messages = []
         for key_set in NUMBERED_KEY_NAMES:
-            # print(key_set)
-            print(message)
             if not message.get('data', {}).get(key_set['street_name']):
-                # print(key_set['street_name'])
-                # # print(message.get('data', {}))
-                # print("EXITING")
                 continue
             new_message = copy.deepcopy(message)
             for key, value in key_set.items():
@@ -149,18 +140,6 @@ def expand_speed_zone(message):
         return [message]
 
 
-def get_linestring_index(map):
-    for i in range(len(map)):
-        if map[i].get("type") == "LineString":
-            return i
-
-
-def get_polygon_index(map):
-    for i in range(len(map)):
-        if map[i].get("type") == "Polygon":
-            return i
-
-
 def get_directions_from_string(directions_string) -> list:
     if not directions_string or type(directions_string) != str:
         return []
@@ -256,12 +235,14 @@ def create_rtdh_standard_msg(pd):
             "type": pd.get("data/constructionType", default=""),
             "source": {
                 "id": pd.get("sys_gUid", default=""),
+                "creation_timestamp": pd.get("data/signature/date", date_tools.get_unix_from_iso_string, default=0),
                 "last_updated_timestamp": date_tools.date_to_unix(datetime.utcnow()),
             },
             "geometry": coordinates,
             "header": {
                 "description": pd.get("data/descriptionForProject", default=""),
                 "justification": pd.get("data/reductionJustification"),
+                "reduced_speed_limit": pd.get("data/requestedTemporarySpeed"),
                 "start_timestamp": date_tools.date_to_unix(start_date),
                 "end_timestamp": date_tools.date_to_unix(end_date),
             },
@@ -270,9 +251,12 @@ def create_rtdh_standard_msg(pd):
                 "road_number": pd.get("data/streetNameFrom"),
                 "direction": direction,
             },
-            # "additional_info": [
-            #
-            # ]
+            "additional_info": {
+                "normal_speed_limit": pd.get("data/currentPostedSpeed"),
+                "mileMarkerStart": pd.get("data/mileMarkerStart"),
+                "mileMarkerEnd": pd.get("data/mileMarkerEnd"),
+                "mileMarkerEnd": pd.get("data/mileMarkerEnd"),
+            }
         }
     }
 
